@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 import datetime
-import pytils
+
+from pytils import dt
 
 # действие ru_strftime аналогично оригинальному strftime
 # только в %a, %A, %b и %B вместо английских названий будут русские
@@ -10,29 +11,35 @@ import pytils
 d = datetime.date(2006, 9, 15)
 
 # оригинал
-print d.strftime("%d.%m.%Y (%a)")
+print(d.strftime("%d.%m.%Y (%a)"))
 # -> 15.09.2006 (Fri)
 
 # теперь на русском
 # (единственно, что нужно формат строки передавать в unicode
 # в то время, как в оригинальном strftime это обязательно str)
-print pytils.dt.ru_strftime(u"%d.%m.%Y (%a)", d)
+print(dt.ru_strftime("%d.%m.%Y (%a)", d))
 # -> 15.09.2006 (пт)
 
 # %A дает полное название дня недели
-print pytils.dt.ru_strftime(u"%d.%m.%Y (%A)", d)
+print(dt.ru_strftime("%d.%m.%Y (%A)", d))
 # -> 15.09.2006 (пятница)
 
 # %B -- название месяца
-print pytils.dt.ru_strftime(u"%d %B %Y", d)
+print(dt.ru_strftime("%d %B %Y", d))
 # -> 15 сентябрь 2006
 
 # ru_strftime умеет правильно склонять месяц (опция inflected)
-print pytils.dt.ru_strftime(u"%d %B %Y", d, inflected=True)
+print(dt.ru_strftime("%d %B %Y", d, inflected=True))
 # -> 15 сентября 2006
 
 # ... и день (опция inflected_day)
-print pytils.dt.ru_strftime(u"%d.%m.%Y, в %A", d, inflected_day=True)
+print(dt.ru_strftime("%d.%m.%Y, в %A", d, inflected_day=True))
+# -> 15.09.2006, в пятницу
+
+# ... и добавлять правильный предлог (опция preposition)
+print(dt.ru_strftime("%d.%m.%Y, %A", d, preposition=True))
+# -> 15.09.2006, в пятницу
 
 # второй параметр можно не передавать, будет использована текущая дата
-print pytils.dt.ru_strftime(u"%d %B %Y", inflected=True)
+print(dt.ru_strftime("%d %B %Y", inflected=True))
+# ->> 1 декабря 2013
\ No newline at end of file
