@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import pytils
+from pytils import numeral
 
 # sum_string объединяет в себе choose_plural и in_words
 # т.е. передаются и количество, и варианты названия объекта
@@ -13,17 +13,17 @@ import pytils
 # 3) items, варианты названий объекта (необязательно),
 #    правила аналогичны таковым у choose_plural
 
-print pytils.numeral.sum_string(3, 1, (u"носок", u"носка", u"носков"))
+print(numeral.sum_string(3, numeral.MALE, ("носок", "носка", "носков")))
 #-> три носка
 
-print pytils.numeral.sum_string(5, 2, (u"коробка", u"коробки", u"коробок"))
+print(numeral.sum_string(5, numeral.FEMALE, ("коробка", "коробки", "коробок")))
 #-> пять коробок
 
-print pytils.numeral.sum_string(21, 3, (u"очко", u"очка", u"очков"))
+print(numeral.sum_string(21, numeral.NEUTER, ("очко", "очка", "очков")))
 #-> двадцать одно очко
 
 # если варианты не указывать, то действие функции аналогично дейтсвию in_words
-print pytils.numeral.sum_string(21, 3)
+print(numeral.sum_string(21, gender=numeral.NEUTER))
 #-> двадцать одно
 
 
